//Reference: https://www.d3-graph-gallery.com/graph/line_basic.html

// set the dimensions and margins of the graph
const lc_margin = { top: 75, right: 30, bottom: 75, left: 75 },
  lc_width = 750 - lc_margin.left - lc_margin.right,
  lc_height = 630 - lc_margin.top - lc_margin.bottom;

// append the svg object to the body of the page
const lc_svg = d3
  .select("#line_chart")
  .append("svg")
  .attr("width", lc_width + lc_margin.left + lc_margin.right)
  .attr("height", lc_height + lc_margin.top + lc_margin.bottom)
  .append("g")
  .attr("transform", `translate(${lc_margin.left},${lc_margin.top})`);

// read the data
d3.csv("linechart.csv", (d) => {
  return { year: d3.timeParse("%Y")(d.year), avg_km_driven: d.avg_km_driven };
}).then((data) => {
  // add chart title
  lc_svg
    .append("text")
    .attr("x", lc_width / 2)
    .attr("y", -50)
    .attr("text-anchor", "middle")
    .text(
      "Used Cars Avg. km Driven by Year"
    );

  // add x axis --> it is a date format
  const x = d3
    .scaleTime()
    .domain(
      d3.extent(data, (d) => {
        return d.year;
      })
    )
    .range([0, lc_width]);
  lc_svg
    .append("g")
    .attr("transform", `translate(0, ${lc_height})`)
    .call(d3.axisBottom(x));

  // add x axis label
  lc_svg
    .append("text")
    .attr("text-anchor", "middle")
    .attr("x", lc_width / 2)
    .attr("y", lc_height + 50)
    .text("Year");

  // add y axis
  const y = d3
    .scaleLinear()
    .domain([
      0,
      d3.max(data, (d) => {
        return +d.avg_km_driven;
      }),
    ])
    .range([lc_height, 0]);
  lc_svg.append("g").call(d3.axisLeft(y));

  // add y axis label:
  lc_svg
    .append("text")
    .attr("text-anchor", "middle")
    .attr("x", -lc_height / 2)
    .attr("y", -50)
    .text("Avg. km Driven")
    .attr("transform", "rotate(-90)");

  // add the line
  lc_svg
    .append("path")
    .datum(data)
    .attr("fill", "none")
    .attr("stroke", "steelblue")
    .attr("stroke-width", 1.5)
    .attr(
      "d",
      d3
        .line()
        .x((d) => {
          return x(d.year);
        })
        .y((d) => {
          return y(d.avg_km_driven);
        })
    );
});
